@@ -26,7 +26,22 @@ REST_BASE_URL = "http://{0}:{1}/as/{2}"
 REST_CHANNEL_LIST = "services"
 REST_FAVOURITES = "services/favourites"
 REST_RECORDING_DETAILS = "pvr/details/{0}"
-REST_RECORDINGS_LIST = "pvr/?limit=1000&offset=0"
+REST_RECORDINGS_LIST = "pvr/?limit={0}&offset={1}"
+REST_QUOTA_DETAILS = "pvr/storage"
+REST_BOOK_RECORDING = "pvr/action/bookrecording?eid={0}"
+REST_BOOK_PPVRECORDING = "pvr/action/bookppvrecording?eid={0}&offerref={1}"
+REST_BOOK_SERIES_RECORDING = "pvr/action/bookseriesrecording?eid={0}"
+REST_SERIES_LINK = "pvr/action/serieslink?pvrid={0}"
+REST_SERIES_UNLINK = "pvr/action/seriesunlink?pvrid={0}"
+REST_RECORDING_KEEP = "pvr/action/keep?pvrid={0}"
+REST_RECORDING_UNKEEP = "pvr/action/unkeep?pvrid={0}"
+REST_RECORDING_LOCK = "pvr/action/lock?pvrid={0}"
+REST_RECORDING_UNLOCK = "pvr/action/unlock?pvrid={0}"
+REST_RECORDING_DELETE = "pvr/action/delete?pvrid={0}"
+REST_RECORDING_UNDELETE = "pvr/action/undelete?pvrid={0}"
+REST_RECORDING_ERASE = "pvr/action/erase?pvrid={0}"
+REST_RECORDING_ERASE_ALL = "pvr"
+REST_RECORDING_SET_LAST_PLAYED_POSITION = "pvr/action/setlastplayedposition?pos={0}&pvrid={1}"
 REST_PATH_SYSTEMINFO = "system/information"
 REST_PATH_DEVICEINFO = "system/deviceinformation"
 REST_PATH_APPS = "apps"
@@ -110,3 +125,8 @@ RESPONSE_OK = 200
 CONNECT_TIMEOUT = 1000
 HTTP_TIMEOUT = 6
 SOAP_TIMEOUT = 2
+
+AUDIO = "audio"
+VIDEO = "video"
+
+ALLRECORDINGS = "all"
